@@ -29,8 +29,7 @@ class DocumentedRouter(DefaultRouter):
                 super().register(
                     f'{name}-list', change_attachment_viewset, name)
 
-
-    def register(self, prefix, viewset, basename=None, base_name=None):
+    def register(self, prefix, viewset, basename=None):
         if getattr(viewset, 'allow_changes', True):
             self.register_viewsets(viewset)
-        super().register(prefix, viewset, basename, base_name)
+        super().register(prefix, viewset, basename)
