@@ -8,7 +8,7 @@ from django.utils import timezone
 from django.db import models
 from django.contrib.postgres.fields import ArrayField
 from django.db.models.signals import class_prepared, post_save
-from django.utils.translation import ugettext, ugettext_lazy as _
+from django.utils.translation import gettext, gettext_lazy as _
 from model_utils import FieldTracker
 
 from .fields import FIELDS_PROCESSORS
@@ -152,7 +152,7 @@ class BaseSnapshot(Dated):
         'Снапшоты вычисляются на основе логической истории')
 
     EXCLUDED_STATE_FIELDS = (
-        'uid', 'deleted', 'created', 'updated', 'version', 'history_date',
+        'guid', 'deleted', 'created', 'updated', 'version', 'history_date',
         'document_fields')
 
     changes = None
@@ -364,7 +364,7 @@ class Changes:
             verbose_name=attachment_title)  # noqa: protected-access
         attrs['document_fields'] = ArrayField(
             models.CharField(_('Атрибуты'), max_length=255), default=list,
-            validators=[LimitedChoicesValidator(documented_fields)])
+            validators=[LimitedChoicesValidator(sorted(documented_fields))])
         base_meta = {
             'ordering': ('-document_date',),
             'get_latest_by': 'document_date'}
@@ -470,13 +470,13 @@ class Changes:
             name = model_opts['verbose_name']
         else:
             template = model_opts['verbose_name_template']
-            name = ugettext(template.format(model=model))
+            name = gettext(template.format(model=model))
 
         if model_opts['verbose_name_plural']:
             name_plural = model_opts['verbose_name_plural']
         else:
             template = model_opts['verbose_name_plural_template']
-            name_plural = ugettext(template.format(model=model))
+            name_plural = gettext(template.format(model=model))
 
         meta_fields['verbose_name'] = name
         meta_fields['verbose_name_plural'] = name_plural
